@@ -67,13 +67,19 @@ class Inspection:
 
     def diff(self, other: "Inspection") -> t.List[str]:
         rv = []
-        for obj_id in nx.topological_sort(self.graph):
-            try:
-                obj = self[obj_id]
-            except KeyError:
-                print(self.objects.keys())
-                raise
 
+        for obj_id in nx.topological_sort(other.graph):
+            if obj_id not in self:
+                try:
+                    other_obj = other[obj_id]
+                except KeyError:
+                    # TODO this should not be happening period.
+                    continue
+                statement = drop(other_obj)
+                rv.append(helpers.format_statement(statement))
+
+        for obj_id in nx.topological_sort(self.graph):
+            obj = self[obj_id]
             try:
                 other_obj = other[obj_id]
             except KeyError:
@@ -83,7 +89,6 @@ class Inspection:
             else:
                 for s in diff(other_obj, obj):
                     rv.append(helpers.format_statement(s))
-
         return rv
 
 
